@@ -56,6 +56,8 @@ This will result in the following files, which are placed in the specified `--ou
     disk image: Create an EFI system partition formatted with the FAT filesystem and place the
     EFI file under `efi\boot\bootx64.efi` on that filesystem.
 
+**You can find some examples that implement the above steps [in our GitHub repo](https://github.com/rust-osdev/bootloader/tree/main/examples).**
+
 ## Configuration
 
 The bootloader can be configured through a `[package.metadata.bootloader]` table in the
@@ -93,13 +95,17 @@ pub mod binary;
 #[cfg(feature = "builder")]
 pub mod disk_image;
 
-#[cfg(target_arch = "x86")]
+#[cfg(all(target_arch = "x86", not(feature = "builder")))]
 compile_error!(
     "This crate currently does not support 32-bit protected mode. \
          See https://github.com/rust-osdev/bootloader/issues/70 for more information."
 );
 
-#[cfg(not(any(target_arch = "x86_64", target_arch = "x86")))]
+#[cfg(all(
+    not(target_arch = "x86_64"),
+    not(target_arch = "x86"),
+    not(feature = "builder")
+))]
 compile_error!("This crate only supports the x86_64 architecture.");
 
 /// Defines the entry point function.
